/* This is "compare1.c", written to accompany Introduction to
   Scientific Programming by Joseph L. Zachary. */

/* Together with "integrate1.c", this is an implementation and a
   test driver for the rectangular and trapezoidal methods of
   numerical integration. */


#include <stdio.h>
#include <math.h>



/* Approximates the definite integral of "integrand" between
   a low bound of "a" and a high bound of "b" using the
   rectangular method with "n" trapezoids. */

double rectangular (double a, double b, int n,
                    double integrand (double));



/* Approximates the definite integral of "integrand" between
   a low bound of "a" and a high bound of "b" using the
   trapezoidal method with "n" trapezoids. */

double trapezoidal (double a, double b, int n,
                    double integrand (double));



/* Returns sin(x)+2. */

double f (double x)
{
  return(sin(x) + 2);
}



/* Test driver for "rectangular" and "trapezoidal". */

void main (void)
{

  int ndivisions;
  double low, high;

  printf("Enter number of divisions: ");
  scanf("%d", &ndivisions);

  printf("Enter low bound of integration: ");
  scanf("%lf", &low);

  printf("Enter high bound of integration: ");
  scanf("%lf", &high);

  printf("Rectangular = %g, trapezoidal = %g\n",
         rectangular(low, high, ndivisions, f),
         trapezoidal(low, high, ndivisions, f));

}
